@@ -70,7 +70,7 @@ claw::arguments_table::argument_attributes::format_short_help() const
 {
   std::string result(m_name);
 
-  if (m_value_type != "")
+  if (!m_value_type.empty())
     result += "=" + m_value_type;
 
   if (m_optional)
@@ -87,7 +87,7 @@ std::string claw::arguments_table::argument_attributes::format_long_help() const
 {
   std::string result(m_name);
 
-  if (m_second_name != "")
+  if ( !m_second_name.empty() )
     result += ", " + m_second_name;
 
   return result + "\t" + m_help_message;
@@ -124,6 +124,17 @@ bool claw::arguments_table::argument_attributes::is_optional() const
 
 
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Constructor.
+ * \param prog_name Force the name of the program.
+ */
+claw::arguments_table::arguments_table( const std::string& prog_name )
+  : m_arguments(prog_name)
+{
+
+} // arguments_table::arguments_table()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
@@ -133,7 +144,7 @@ bool claw::arguments_table::argument_attributes::is_optional() const
  * All supported arguments will be removed from argv.
  */
 claw::arguments_table::arguments_table( int& argc, char** &argv )
-  : m_arguments(argc, argv)
+  : m_arguments(argc, argv, claw::math::ordered_set<std::string>() )
 {
 
 } // arguments_table::arguments_table()
@@ -229,29 +240,31 @@ void claw::arguments_table::help( const std::string& free_args ) const
 {
   std::cout << m_arguments.get_program_name();
 
-  std::list<argument_attributes> optional;
-  std::list<argument_attributes>::const_iterator it_opt;
-  math::ordered_set<argument_attributes>::const_iterator it;
+  typedef math::ordered_set<argument_attributes>::const_iterator set_iterator;
+
+  std::list<set_iterator> optional;
+  std::list<set_iterator>::const_iterator it_opt;
+  set_iterator it;
 
   for (it=m_short_arguments.begin(); it!=m_short_arguments.end(); ++it)
     if ( it->is_optional() )
-      optional.push_back(*it);
+      optional.push_back(it);
     else
       std::cout << " " << it->format_short_help();
 
   for (it=m_long_arguments.begin(); it!=m_long_arguments.end(); ++it)
-    if (it->get_second_name() == "")
+    if (it->get_second_name().empty())
       {
 	if ( it->is_optional() )
-	  optional.push_back(*it);
+	  optional.push_back(it);
 	else
 	  std::cout << " " << it->format_short_help();
       }
 
   for (it_opt=optional.begin(); it_opt!=optional.end(); ++it_opt)
-    std::cout << " " << it_opt->format_short_help();
+    std::cout << " " << (*it_opt)->format_short_help();
 
-  if ( free_args != "" )
+  if ( !free_args.empty() )
     std::cout << " " << free_args;
 
   std::cout << "\n\n";
@@ -260,7 +273,7 @@ void claw::arguments_table::help( const std::string& free_args ) const
     std::cout << "\t" << it->format_long_help() << std::endl;
 
   for (it=m_long_arguments.begin(); it!=m_long_arguments.end(); ++it)
-    if (it->get_second_name() == "")
+    if (it->get_second_name().empty())
       std::cout << "\t" << it->format_long_help() << std::endl;
 } // arguments_table::help()
 
@@ -301,16 +314,70 @@ bool claw::arguments_table::has_value( const std::string& arg_name ) const
 
   get_argument_names( arg_name, short_name, long_name );
 
-  if ( short_name != "" )
+  if ( !short_name.empty() )
     result = m_arguments.has_value(short_name);
 
   if (!result)
-    if ( long_name != "" )
+    if ( !long_name.empty() )
       result = m_arguments.has_value(long_name);
 
   return result;
 } // arguments_table::has_value()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if only integer values are associated to an argument.
+ * \param arg_name The name of the argument to test.
+ */
+bool
+claw::arguments_table::only_integer_values( const std::string& arg_name ) const
+{
+  bool result = true;
+  std::string short_name, long_name;
+
+  get_argument_names( arg_name, short_name, long_name );
+
+  if ( short_name.empty() && long_name.empty() )
+    result = false;
+  else
+    {
+      if ( !short_name.empty() )
+        result = m_arguments.only_integer_values(short_name);
+
+      if ( !long_name.empty() )
+        result = result && m_arguments.only_integer_values(long_name);
+    }
+
+  return result;
+} // arguments_table::only_integer_values()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if only real values are associated to an argument.
+ * \param arg_name The name of the argument to test.
+ */
+bool
+claw::arguments_table::only_real_values( const std::string& arg_name ) const
+{
+  bool result = true;
+  std::string short_name, long_name;
+
+  get_argument_names( arg_name, short_name, long_name );
+
+  if ( short_name.empty() && long_name.empty() )
+    result = false;
+  else
+    {
+      if ( !short_name.empty() )
+        result = m_arguments.only_real_values(short_name);
+
+      if ( !long_name.empty() )
+        result = result && m_arguments.only_real_values(long_name);
+    }
+
+  return result;
+} // arguments_table::only_real_values()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the name of the program.
@@ -395,6 +462,81 @@ claw::arguments_table::get_string( const std::string& arg_name ) const
     return m_arguments.get_string(long_name);
 } // arguments_table::get_string()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get all integer values of an argument.
+ * \param arg_name The name of the argument to get.
+ */
+std::list<int>
+claw::arguments_table::get_all_of_integer( const std::string& arg_name ) const
+{
+  std::list<int> result;
+  std::string short_name, long_name;
+
+  get_argument_names( arg_name, short_name, long_name );
+
+  if ( !short_name.empty() )
+    result = m_arguments.get_all_of_integer(short_name);
+
+  if ( !long_name.empty() )
+    {
+      const std::list<int> p(m_arguments.get_all_of_integer(long_name));
+      result.insert( result.end(), p.begin(), p.end() );
+    }
+
+  return result;
+} // arguments_table::get_all_of_integer()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get all real values of an argument.
+ * \param arg_name The name of the argument to get.
+ */
+std::list<double>
+claw::arguments_table::get_all_of_real( const std::string& arg_name ) const
+{
+  std::list<double> result;
+  std::string short_name, long_name;
+
+  get_argument_names( arg_name, short_name, long_name );
+
+  if ( !short_name.empty() )
+    result = m_arguments.get_all_of_real(short_name);
+
+  if ( !long_name.empty() )
+    {
+      const std::list<double> p(m_arguments.get_all_of_real(long_name));
+      result.insert( result.end(), p.begin(), p.end() );
+    }
+
+  return result;
+} // arguments_table::get_all_of_real()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get all string values of an argument.
+ * \param arg_name The name of the argument to get.
+ */
+std::list<std::string>
+claw::arguments_table::get_all_of_string( const std::string& arg_name ) const
+{
+  std::list<std::string> result;
+  std::string short_name, long_name;
+
+  get_argument_names( arg_name, short_name, long_name );
+
+  if ( !short_name.empty() )
+    result = m_arguments.get_all_of_string(short_name);
+
+  if ( !long_name.empty() )
+    {
+      const std::list<std::string> p(m_arguments.get_all_of_string(long_name));
+      result.insert( result.end(), p.begin(), p.end() );
+    }
+
+  return result;
+} // arguments_table::get_all_of_string()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add an argument in our list.
